@@ -22,12 +22,15 @@ from alchemite_apiclient.calculated_columns.helpers import (
     column,
     cos,
     cosh,
+    e,
     if_,
     literal,
     ln,
     max_,
     mean,
     min_,
+    nan,
+    pi,
     product,
     sin,
     sinh,
@@ -72,4 +75,7 @@ __all__ = [
     "max_",
     "avg",
     "if_",
+    "e",
+    "pi",
+    "nan",
 ]
