@@ -93,6 +93,7 @@ from alchemite_apiclient.model.extension import Extension
 from alchemite_apiclient.model.extension_infocol import ExtensionInfocol
 from alchemite_apiclient.model.extension_infocol_arguments import ExtensionInfocolArguments
 from alchemite_apiclient.model.extension_oligo import ExtensionOligo
+from alchemite_apiclient.model.extension_smiles import ExtensionSmiles
 from alchemite_apiclient.model.favourite_dataset import FavouriteDataset
 from alchemite_apiclient.model.favourite_job import FavouriteJob
 from alchemite_apiclient.model.favourite_patch import FavouritePatch
@@ -148,6 +149,7 @@ from alchemite_apiclient.model.hyperopt_target_function import HyperoptTargetFun
 from alchemite_apiclient.model.importance_request import ImportanceRequest
 from alchemite_apiclient.model.impute_request import ImputeRequest
 from alchemite_apiclient.model.inline_object import InlineObject
+from alchemite_apiclient.model.inline_object1 import InlineObject1
 from alchemite_apiclient.model.inline_response200 import InlineResponse200
 from alchemite_apiclient.model.inline_response2001 import InlineResponse2001
 from alchemite_apiclient.model.inline_response2002 import InlineResponse2002
@@ -155,7 +157,9 @@ from alchemite_apiclient.model.inline_response2003 import InlineResponse2003
 from alchemite_apiclient.model.inline_response2003_normalization_values import InlineResponse2003NormalizationValues
 from alchemite_apiclient.model.inline_response2003_values import InlineResponse2003Values
 from alchemite_apiclient.model.inline_response2004 import InlineResponse2004
+from alchemite_apiclient.model.inline_response2004_values import InlineResponse2004Values
 from alchemite_apiclient.model.inline_response2005 import InlineResponse2005
+from alchemite_apiclient.model.inline_response2006 import InlineResponse2006
 from alchemite_apiclient.model.int_cat_arr import IntCatArr
 from alchemite_apiclient.model.interaction_plot_data import InteractionPlotData
 from alchemite_apiclient.model.job_favourite_query import JobFavouriteQuery
