@@ -1,11 +1,7 @@
-from __future__ import print_function
-
 import csv
 from io import StringIO
 
 import alchemite_apiclient as client
-import matplotlib.pyplot as plt
-import pandas as pd
 from alchemite_apiclient.extensions import Configuration, await_trained
 
 configuration = Configuration()
@@ -39,7 +35,9 @@ output_impute_file = "output_impute_categorical.csv"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
