@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 from io import StringIO
 
@@ -27,7 +25,9 @@ model_name = "steels"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
@@ -124,11 +124,9 @@ api_datasets.datasets_id_column_groups_column_group_id_patch(
     },
 )
 
-modified_column_group = (
-    api_datasets.datasets_id_column_groups_column_group_id_get(
-        dataset_id,
-        column_group_id,
-    )
+modified_column_group = api_datasets.datasets_id_column_groups_column_group_id_get(
+    dataset_id,
+    column_group_id,
 )
 
 print("--- new column group ---")
