@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import alchemite_apiclient as client
 from alchemite_apiclient.extensions import Configuration
 
@@ -17,7 +15,9 @@ model_id_to_delete = "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 # Can iterate through all models and delete a model with a particular ID.
