@@ -184,7 +184,7 @@ dimensionality_reduction_response = (
         dimensionality_reduction_request=dimensionality_reduction_request,
     )
 )
-while dimensionality_reduction_response is None:
+while not dimensionality_reduction_response:
     time.sleep(1)
     dimensionality_reduction_response = (
         api_datasets.datasets_id_dimensionality_reduction_put(
