@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import alchemite_apiclient as client
 from alchemite_apiclient.extensions import Configuration
 
@@ -16,7 +14,9 @@ dataset_id_to_download = "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 r = api_datasets.datasets_id_download_get(dataset_id_to_download)
