@@ -1,12 +1,9 @@
-from __future__ import print_function
-
 import csv
 import json
 from io import StringIO
 
 import alchemite_apiclient as client
-from alchemite_apiclient.extensions import (Configuration, await_job,
-                                            await_trained)
+from alchemite_apiclient.extensions import Configuration, await_job, await_trained
 
 configuration = Configuration()
 api_default = client.DefaultApi(client.ApiClient(configuration))
@@ -16,28 +13,18 @@ api_datasets = client.DatasetsApi(client.ApiClient(configuration))
 ### Provide path to the JSON containing your credentials
 configuration.credentials = "credentials.json"
 
-OPTIMIZE_DATASET = (
-    "steels"  # 'steels' or 'vector' or 'steels dependent columns'
-)
+OPTIMIZE_DATASET = "steels"  # 'steels' or 'steels dependent columns'
 
 if OPTIMIZE_DATASET == "steels":
     dataset_file = "steels.csv"
     dataset_name = "steels"
     model_name = "steels"
     optimize_args = "optimize_args_steel.json"
-    vector_pairs = None
 elif OPTIMIZE_DATASET == "steels dependent columns":
     dataset_file = "steels.csv"
     dataset_name = "steels"
     model_name = "steels"
     optimize_args = "optimize_dependentColumns_args_steel.json"
-    vector_pairs = None
-elif OPTIMIZE_DATASET == "vector":
-    dataset_file = "vector.csv"
-    dataset_name = "vector"
-    model_name = "vector"
-    optimize_args = "optimize_args_vector.json"
-    vector_pairs = [["z", "t"]]
 else:
     raise Exception("Invalid optimize dataset option")
 
@@ -45,7 +32,9 @@ else:
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
@@ -65,7 +54,6 @@ dataset = {
     # No descriptors in this dataset so list of zeros
     "descriptor_columns": [0] * len(column_headers),
     "data": data,
-    "vector_pairs": vector_pairs,
 }
 dataset_id = api_datasets.datasets_post(dataset=dataset)
 print("dataset ID:", dataset_id)
@@ -93,8 +81,8 @@ print("model ID:", model_id)
 ### Start training the model
 ############################################################################
 train_request = {
-    "validation":"none",
-    "hyperparameter_optimization":"none",
+    "validation": "none",
+    "hyperparameter_optimization": "none",
 }
 response = api_models.models_id_train_put(model_id, train_request=train_request)
 print(response)
@@ -128,11 +116,10 @@ with open(optimize_args, encoding="UTF-8") as f:
 optimize_job_id = api_models.models_id_optimize_post(model_id, **optimize_args)
 print("Optimize job ID:", optimize_job_id)
 
+
 # Wait until the optimize job has finished
 def get_optimize_job_metadata():
-    return api_models.models_id_optimize_job_id_get(
-        model_id, job_id=optimize_job_id
-    )
+    return api_models.models_id_optimize_job_id_get(model_id, job_id=optimize_job_id)
 
 
 optimize_job = await_job(get_optimize_job_metadata)
