@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 from io import StringIO
 
@@ -15,26 +13,17 @@ api_datasets = client.DatasetsApi(client.ApiClient(configuration))
 ### Provide path to the JSON containing your credentials
 configuration.credentials = "credentials.json"
 
-SUGGEST_DATASET = "steels"  # 'steels' or 'vector'
-
-if SUGGEST_DATASET == "steels":
-    dataset_file = "steels.csv"
-    dataset_name = "steels"
-    model_name = "steels"
-    vector_pairs = None
-elif SUGGEST_DATASET == "vector":
-    dataset_file = "vector.csv"
-    dataset_name = "vector"
-    model_name = "vector"
-    vector_pairs = [["z", "t"]]
-else:
-    raise Exception("Invalid suggest dataset option")
+dataset_file = "steels.csv"
+dataset_name = "steels"
+model_name = "steels"
 
 # Check we can access the API by getting the version number from GET /version
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
@@ -54,7 +43,6 @@ dataset = {
     # No descriptors in this dataset so list of zeros
     "descriptor_columns": [0] * len(column_headers),
     "data": data,
-    "vector_pairs": vector_pairs,
 }
 dataset_id = api_datasets.datasets_post(dataset=dataset)
 print("dataset ID:", dataset_id)
