@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 from io import StringIO
 
@@ -36,7 +34,9 @@ training_datset_outliers_file = "adrenergic_outliers.csv"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
