@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 import json
 from io import StringIO
@@ -45,7 +43,9 @@ holdout_analysis_file = "adrenergic_holdout_analysis.json"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
