@@ -2,6 +2,8 @@ from io import StringIO
 
 import pandas as pd
 
+from alchemite_apiclient.extensions import await_uploaded
+
 
 def test_download(
     set_insecure_transport,
@@ -13,6 +15,8 @@ def test_download(
     column_headers = dataset_response["column_headers"]
     row_count = dataset_response["row_count"]
 
+    await_uploaded(lambda: api_datasets.datasets_id_get(dataset_id_to_download))
+
     download_response = api_datasets.datasets_id_download_get(
         dataset_id_to_download, _preload_content=False
     )
