@@ -1,12 +1,7 @@
 import os
-import sys
-import time
-from statistics import mean
 
 
-def test_preload(
-    set_insecure_transport, api_models, adrenergic_model, example_dir
-):
+def test_preload(set_insecure_transport, api_models, adrenergic_model, example_dir):
     model_id = adrenergic_model
     impute_input_file = os.path.join(example_dir, "adrenergic_row.csv")
 
