@@ -5,18 +5,14 @@ from alchemite_apiclient.extensions import await_job
 
 
 def test_suggest_initial(set_insecure_transport, api_default, example_dir):
-    suggest_initial_args_path = os.path.join(
-        example_dir, "suggest_initial_args.json"
-    )
+    suggest_initial_args_path = os.path.join(example_dir, "suggest_initial_args.json")
 
     # Make a suggest initial request
     with open(suggest_initial_args_path, encoding="UTF-8") as f:
         suggest_initial_args = json.load(f)
 
     # Send suggest_initial request
-    suggest_initial_job_id = api_default.suggest_initial_post(
-        **suggest_initial_args
-    )
+    suggest_initial_job_id = api_default.suggest_initial_post(**suggest_initial_args)
 
     # Wait until the suggest_initial job has finished
     def get_suggest_initial_job_metadata():
@@ -27,7 +23,5 @@ def test_suggest_initial(set_insecure_transport, api_default, example_dir):
     assert suggest_initial_response["status"] == "done"
 
     # Delete suggest_initial job
-    delete_response = api_default.suggest_initial_job_id_delete(
-        suggest_initial_job_id
-    )
-    assert delete_response is None
+    delete_response = api_default.suggest_initial_job_id_delete(suggest_initial_job_id)
+    assert delete_response == ""
